<p align="center">
<img src="https://www.kima.science/assets/logo_transparent.png" 
     width="200" alt="Logo created by Solène Ulmer-Moll">

<p align="center">
     A data analysis framework for exoplanet detection
</p>
</p>


<div align = center>
<br>
     
[![Button Shield]][Shield]

</div>


<!---------------------------------------------------------------------------->
[Button Shield]: https://img.shields.io/badge/Documentation-009485?style=for-the-badge
[Shield]: https://www.kima.science/docs

